[svn] commit: r3121 - in /branches/vorner-sockcreator/src/bin/sockcreator: Makefile.am main.cc sockcreator.cc sockcreator.h

BIND 10 source code commits bind10-changes at lists.isc.org
Tue Oct 5 14:56:32 UTC 2010


Author: vorner
Date: Tue Oct  5 14:56:15 2010
New Revision: 3121

Log:
Dummy implementation of the socket creator

Only empty functions, so it compiles at last.

Added:
    branches/vorner-sockcreator/src/bin/sockcreator/main.cc
    branches/vorner-sockcreator/src/bin/sockcreator/sockcreator.cc
Modified:
    branches/vorner-sockcreator/src/bin/sockcreator/Makefile.am
    branches/vorner-sockcreator/src/bin/sockcreator/sockcreator.h

Modified: branches/vorner-sockcreator/src/bin/sockcreator/Makefile.am
==============================================================================
--- branches/vorner-sockcreator/src/bin/sockcreator/Makefile.am (original)
+++ branches/vorner-sockcreator/src/bin/sockcreator/Makefile.am Tue Oct  5 14:56:15 2010
@@ -1,5 +1,7 @@
 SUBDIRS = tests
+
+CLEANFILES = *.gcno *.gcda
 
 pkglibexec_PROGRAMS = b10-sockcreator
 
-b10_sockcreator_SOURCES = sockcreator.h
+b10_sockcreator_SOURCES = sockcreator.cc sockcreator.h main.cc

Modified: branches/vorner-sockcreator/src/bin/sockcreator/sockcreator.h
==============================================================================
--- branches/vorner-sockcreator/src/bin/sockcreator/sockcreator.h (original)
+++ branches/vorner-sockcreator/src/bin/sockcreator/sockcreator.h Tue Oct  5 14:56:15 2010
@@ -41,17 +41,17 @@
  *     errno is set (or better, left intact from socket() or bind()).
  * \param type The type of socket to create (SOCK_STREAM, SOCK_DGRAM, etc).
  * \param bind_addr The address to bind.
  * \param addrlen The actual length of bind_addr.
  */
 int
-get_sock(const int type, struct sockaddr *bind_addr, const socklen_t addrlen);
+get_sock(const int type, struct sockaddr *bind_addr, const socklen_t addr_len);
 
 /**
  * Type of the get_sock function, to pass it as parameter.
  */
 typedef
 int
-(*get_sock_t)(const int, struct sockaddr, const socklen_t);
+(*get_sock_t)(const int, struct sockaddr *, const socklen_t);
 
 /**
  * Sends a payload socket file descriptor to destination file descriptor.
@@ -96,7 +96,7 @@
     const get_sock_t get_sock_fun = get_sock,
     const send_fd_t send_fd_fun = send_fd);
 
-}
+} // End of the namespaces
 }
 
 #endif // __SOCKCREATOR_H
@@ -41,17 +41,17 @@
  * \param type The type of socket to create (SOCK_STREAM, SOCK_DGRAM, etc).
  * \param bind_addr The address to bind.
- * \param addrlen The actual length of bind_addr.
+ * \param addr_len The actual length of bind_addr.
  */
 int




More information about the bind10-changes mailing list